@@ -17,9 +17,6 @@ class Application(tornado.web.Application):
             [("/", MultipleRequestHandler), ("/stats", StatsRequestHandler), ("/(.+)", KeyRequestHandler)],
             auto_etag=False)
 
-    def log_request(self, handler):
-        pass
-
 
 class KeyRequestHandler(tornado.web.RequestHandler):
     def get(self, key):
